.. _biomechanics_explanations:

============
Biomechanics
============

This documentation covers the components of :obj:`sympy.physics.biomechanics`.
The :obj:`sympy.physics.biomechanics` module offers features to augment models
developed with :obj:`sympy.physics.mechanics` by incorporating force-generating elements
that simulate biomechanical systems.

Guide to Biomechanics
=====================

.. toctree::
   :maxdepth: 2

   biomechanics.rst
